@@ -318,6 +318,8 @@ def process_excel_file(
 
     jira_query_result = jira_client.get_stories_status(stories_has_story_id)
 
+    print("Quering all stories' status...")
+
     stories_need_sort = []
     stories_no_need_sort = []
 
@@ -334,7 +336,11 @@ def process_excel_file(
             if len(temp_result) > 0:
                 story["storyId"] = list(temp_result.keys())[0]
                 story["status"] = list(temp_result.values())[0]
+                print(
+                    f"Story id has been changed. Previous: {story_id}, Current: {story['storyId']}"
+                )
             else:
+                print(f"Cannot find status information for story: {story_id}")
                 stories_no_need_sort.append(story)
                 continue
 
@@ -359,6 +365,7 @@ def process_excel_file(
             stories_need_sort = sort_stories_by_raise_ranking(
                 stories_need_sort, excel_definition, sort_strategy["config"]
             )
+        print(f"Executed {sort_strategy['name']} sorting")
 
     output_to_excel_file(
         output_file,
