@@ -315,15 +315,19 @@ def sort_stories_by_raise_ranking(
     if len(sort_rules) == 0:
         return stories
 
-    sort_rules.sort(key=lambda x: x[1], reverse=True)
+    sort_rules.sort(key=lambda x: x[1], reverse=True)  # sort by raise_ranking
 
     result = []
 
     # New raise ranking mode.
     if "ParentLevelIndexRange" in config:
+        column_definitions: dict[int, ExcelDefinitionColumn] = {
+            c["index"]: c for c in excel_definition_columns
+        }
+
         result = _raise_story_ranking_by_property_v2(
             stories,
-            excel_definition_columns,
+            column_definitions,
             sort_rules,
             config["ParentLevelIndexRange"],
         )
@@ -360,13 +364,37 @@ def _raise_story_ranking_by_property(
 
 def _raise_story_ranking_by_property_v2(
     stories: "list[Story]",
-    story_columns: "list[ExcelDefinitionColumn]",
+    story_columns: "dict[int, ExcelDefinitionColumn]",
     sort_rules: "list[tuple[str, int, Optional[set]]]",
     parent_level_index_range: "set[int]",
 ) -> "list[Story]":
-    # begin_index = 0
-    # end_index = 0
-    # for i in range(begin_index, len(stories) - 1):
-    #    for column_index in parent_level_index_range:
-    #        if stories[i][story_columns[column_index]]
+    begin_index = 0
+    end_index = 0
+    while end_index <= len(stories) - 1:
+        for i in range(begin_index, len(stories) - 1):
+            all_parent_column_matched = True
+            for column_index in parent_level_index_range:
+                if (
+                    stories[i][story_columns[column_index]["name"]]
+                    != stories[i + 1][story_columns[column_index]["name"]]
+                ):
+                    all_parent_column_matched = False
+                    break
+            if all_parent_column_matched:
+                continue
+            else:
+                end_index = i
+                break
+        # Same parent level process
+        stories[begin_index : end_index + 1]
+        for column_name, _, _ in reversed(sort_rules):
+            stories[begin_index : end_index + 1] = sorted(
+                stories[begin_index : end_index + 1],
+                key=attrgetter(column_name),
+                reverse=True,
+            )
+
+        begin_index = end_index + 1
+        end_index = begin_index
+
     return stories
